@@ -57,26 +57,6 @@ class ScreenElement(object):
         self._scroll_to_element: bool = scroll_to_element
         self._coordinates: dict = {}
 
-    @aspect.log
-    def _refresh(self, obj):  # the most important method
-        """
-       Refreshes the container of the WebElement in the DOM each time it is referenced,
-       waits for element to fulfil conditions based on objects' properties.
-
-       :param obj: instance of class that owns the property
-       :raises: :exc:`selenium.common.exceptions.TimeoutException` if timeout occurs
-       """
-        self._resolve_fail_message()
-        wdw = WebDriverWait(obj.driver, self._wait, self._poll_frequency, self._ignored_exceptions)
-        if self._until_not:
-            self.driver = wdw.until_not(self._verify_method(self._locator), self._fail_message)
-        else:
-            self.driver = wdw.until(self._verify_method(self._locator), self._fail_message)
-        if isinstance(self.driver, EventFiringWebElement):
-            self.driver = self.driver.wrapped_element
-        if self._scroll_to_element:
-            self._coordinates = self.driver.location_once_scrolled_into_view
-
     @aspect.log
     def _resolve_fail_message(self):
         locator = self._locator if self._locator else 'out'
@@ -87,23 +67,31 @@ class ScreenElement(object):
             self._fail_message = f'Element with{locator} locator did not {appearance} in {self._wait} seconds!'
 
     @aspect.log
-    def set_locator(self, locator: tuple[str, str]):
-        """If not set in constructor, setting locator enables use of object as a WebDriver"""
-        try:
-            assert locator is not None
-            isinstance(locator, tuple)
-            assert len(locator) == 2
-            assert type(locator[0]) == type(locator[1]) == str
-            self._locator = locator
-        except Exception as e:
-            logger.error('Locator should be <tuple[str, str]> with 2 string elements e.g ("id", "someID")')
-            logger.error('\n'.join([str(e), traceback.format_exc()]))
-            raise e
-        logger.info(f'Locator {self._locator} is set on <{self.__class__.__name__}> instance')
+    def _refresh(self, obj):  # the most important method
+        """
+       Refreshes the container of the WebElement in the DOM each time it is referenced,
+       waits for element to fulfil conditions based on objects' properties.
+
+       :param obj: instance of class that owns the property
+       :raises: :exc:`selenium.common.exceptions.TimeoutException` if timeout occurs
+       """
+        if isinstance(self.driver, EventFiringWebElement):
+            self.driver = self.driver.wrapped_element
+        self._resolve_fail_message()
+        wdw = WebDriverWait(obj.driver, self._wait, self._poll_frequency, self._ignored_exceptions)
+        if self._until_not:
+            self.driver = wdw.until_not(self._verify_method(self._locator), self._fail_message)
+        else:
+            self.driver = wdw.until(self._verify_method(self._locator), self._fail_message)
+        if self._scroll_to_element:
+            self._coordinates = self.driver.location_once_scrolled_into_view
 
     @aspect.log
-    def __get__(self, obj, owner):
-        """Gets the ScreenElement or WebElement based on condition if locator property is set"""
+    def locator_is_none(self, obj):
+        """
+        When inheriting the screen element and overriding the __get__ method, it is preferable to call this method first.
+        The method is intended to solve cases when the locator is not set during the construction of the element itself
+        """
         if self._locator is None:
             logger.warning(
                 f' <locator> is not set for <{self.__class__.__name__}>'
@@ -111,6 +99,31 @@ class ScreenElement(object):
                 f' This will raise Attribute Error if called as <WebElement> object.'
             )
             logger.info(f'Getting <{self.__class__.__name__}> instance...')
+            return True
+        return False
+
+    @aspect.log
+    def set_locator(self, locator: tuple[str, str]):
+        """If not set in constructor, setting locator enables use of object as a WebDriver"""
+        try:
+            assert locator is not None
+            assert len(locator) == 2
+            assert type(locator[0]) == type(locator[1]) == str
+            isinstance(locator, tuple)
+            self._locator = locator
+        except Exception as e:
+            logger.error('Locator should be <tuple[str, str]> with 2 string elements e.g ("id", "someID")')
+            logger.error('\n'.join([str(e), traceback.format_exc()]))
+            raise e
+        logger.info(f'Setting locator {self._locator} on <{self.__class__.__name__}> instance')
+
+    @aspect.log
+    def __get__(self, obj, owner):
+        """
+        Gets the ScreenElement or WebElement based on condition if locator property is set.
+        When overriding the ScreenElement "if" block is desirable to handle cases when locator is not set in constructor
+        """
+        if self.locator_is_none(obj):
             return self
         else:
             self._refresh(obj)
@@ -137,8 +150,12 @@ class SectionElement(ScreenElement):
 
     def __get__(self, obj, owner):
         """Gets the section with WebElements"""
-        self._refresh(obj)
-        return self
+        super(SectionElement, self).__get__(obj, owner)
+        if self.locator_is_none(obj):
+            return self
+        else:
+            self._refresh(obj)
+            return self
 
 
 @aspect.log
@@ -154,6 +171,7 @@ class InputElement(ScreenElement):
     def __get__(self, obj, owner):
         """Gets the text of the specified object"""
         super(InputElement, self).__get__(obj, owner)
+        self.locator_is_none(obj)
         self._refresh(obj)
         return self.driver.get_attribute("value")
 
@@ -165,6 +183,7 @@ class LabelElement(ScreenElement):
     def __get__(self, obj, owner):
         """Gets the text of the specified object"""
         super(LabelElement, self).__get__(obj, owner)
+        self.locator_is_none(obj)
         self._refresh(obj)
         return self.driver.text
 
@@ -187,6 +206,7 @@ class SelectElement(ScreenElement):
     def __get__(self, obj, owner):
         """Gets the text of the selected object in dropdown"""
         super(SelectElement, self).__get__(obj, owner)
+        self.locator_is_none(obj)
         self._refresh(obj)
         selected_option = Select(self.driver).first_selected_option
         self.text = selected_option.text.strip()
@@ -282,6 +302,7 @@ class TableElement(ScreenElement):
     """
 
     def __init__(self, table_body_locator, table_row_model_cls):
+        # noinspection PyTypeChecker
         super(TableElement, self).__init__(locator=table_body_locator, method=ec.presence_of_all_elements_located)
         self._table_entry_cls = table_row_model_cls
 
